@@ -1,7 +1,6 @@
+use strict; use warnings;
 package IO::All::Pipe;
 
-use strict;
-use warnings;
 use IO::All -base;
 use IO::File;
 
